@@ -7,9 +7,11 @@ from airflow import AirflowException
 from airflow.models.baseoperator import BaseOperator
 from airflow.utils.decorators import apply_defaults
 from dbt.contracts.results import RunResult
+import dbt.flags as flags
 from dbt.main import adapter_management
 from dbt.main import initialize_config_values
 from dbt.main import parse_args
+from dbt.main import track_run
 from dbt.logger import log_manager
 
 
@@ -35,7 +37,7 @@ class DbtBaseOperator(BaseOperator):
     """
 
     task: Optional[str] = None
-    __slots__ = (
+    __dbt_args__ = [
         "project_dir",
         "profiles_dir",
         "profile",
@@ -43,7 +45,7 @@ class DbtBaseOperator(BaseOperator):
         "vars",
         "log_cache_events",
         "bypass_cache",
-    )
+    ]
 
     @apply_defaults
     def __init__(
@@ -82,7 +84,7 @@ class DbtBaseOperator(BaseOperator):
     def args_list(self) -> list[str]:
         """Build a list of arguments to pass to dbt"""
         args = []
-        for arg in self.__slots__:
+        for arg in self.__dbt_args__:
             value = getattr(self, arg, None)
             if value is None:
                 continue
@@ -112,22 +114,33 @@ class DbtBaseOperator(BaseOperator):
 
     def run_dbt_task(self, args: list[Optional[str]]) -> tuple[RunResult, bool]:
         """Run a dbt task as implemented by a subclass"""
-        try:
-            parsed = parse_args(args)
-        except Exception as exc:
-            raise AirflowException("Failed to parse dbt arguments: {args}") from exc
+        with log_manager.applicationbound():
+            try:
+                parsed = parse_args(args)
+            except Exception as exc:
+                raise AirflowException("Failed to parse dbt arguments: {args}") from exc
 
-        initialize_config_values(parsed)
+            initialize_config_values(parsed)
+            results = None
+            with adapter_management():
+                flags.set_from_args(parsed)
 
-        results = None
-        with adapter_management():
-            parsed.cls.pre_init_hook(parsed)
-            task = parsed.cls.from_args(args=parsed)
-            results = task.run()
+                parsed.cls.pre_init_hook(parsed)
+                task = parsed.cls.from_args(args=parsed)
 
-        success = task.interpret_results(results)
+                log_manager.reset_handlers()
+                log_path = None
+                if task.config is not None:
+                    log_path = getattr(task.config, "log_path", None)
 
-        return results, success
+                log_manager.set_path(log_path)
+
+                with track_run(task):
+                    results = task.run()
+
+                success = task.interpret_results(results)
+
+                return results, success
 
 
 class DbtRunOperator(DbtBaseOperator):
@@ -135,7 +148,7 @@ class DbtRunOperator(DbtBaseOperator):
 
     task = "run"
 
-    __slots__ = DbtBaseOperator.__slots__ + (
+    __dbt_args__ = DbtBaseOperator.__dbt_args__ + [
         "full_refresh",
         "models",
         "fail_fast",
@@ -145,7 +158,7 @@ class DbtRunOperator(DbtBaseOperator):
         "state",
         "defer",
         "no_defer",
-    )
+    ]
 
     def __init__(
         self,
@@ -177,7 +190,7 @@ class DbtSeedOperator(DbtBaseOperator):
 
     task = "seed"
 
-    __slots__ = DbtBaseOperator.__slots__ + (
+    __dbt_args__ = DbtBaseOperator.__dbt_args__ + [
         "full_refresh",
         "select",
         "show",
@@ -185,7 +198,7 @@ class DbtSeedOperator(DbtBaseOperator):
         "exclude",
         "selector",
         "state",
-    )
+    ]
 
     def __init__(
         self,
@@ -213,7 +226,7 @@ class DbtTestOperator(DbtBaseOperator):
 
     task = "test"
 
-    __slots__ = DbtBaseOperator.__slots__ + (
+    __dbt_args__ = DbtBaseOperator.__dbt_args__ + [
         "data",
         "schema",
         "fail_fast",
@@ -224,7 +237,7 @@ class DbtTestOperator(DbtBaseOperator):
         "state",
         "defer",
         "no_defer",
-    )
+    ]
 
     def __init__(
         self,
@@ -258,7 +271,7 @@ class DbtCompileOperator(DbtBaseOperator):
 
     task = "compile"
 
-    __slots__ = DbtBaseOperator.__slots__ + (
+    __dbt_args__ = DbtBaseOperator.__dbt_args__ + [
         "parse_only",
         "full_refresh",
         "fail_fast",
@@ -267,7 +280,7 @@ class DbtCompileOperator(DbtBaseOperator):
         "exclude",
         "selector",
         "state",
-    )
+    ]
 
     def __init__(
         self,
@@ -315,7 +328,7 @@ class DbtDebugOperator(DbtBaseOperator):
 
     task = "debug"
 
-    __slots__ = DbtBaseOperator.__slots__ + ("config_dir", "no_version_check")
+    __dbt_args__ = DbtBaseOperator.__dbt_args__ + ["config_dir", "no_version_check"]
 
     def __init__(
         self,
@@ -333,13 +346,13 @@ class DbtSnapshotOperator(DbtBaseOperator):
 
     task = "snapshot"
 
-    __slots__ = DbtBaseOperator.__slots__ + (
+    __dbt_args__ = DbtBaseOperator.__dbt_args__ + [
         "select",
         "threads",
         "exclude",
         "selector",
         "state",
-    )
+    ]
 
     def __init__(
         self,
@@ -363,14 +376,14 @@ class DbtLsOperator(DbtBaseOperator):
 
     task = "ls"
 
-    __slots__ = DbtBaseOperator.__slots__ + (
+    __dbt_args__ = DbtBaseOperator.__dbt_args__ + [
         "resource_type",
         "select",
         "models",
         "exclude",
         "selector",
         "dbt_output",
-    )
+    ]
 
     def __init__(
         self,
